cosinnus.core.registries package
================================

Submodules
----------

cosinnus.core.registries.apps module
------------------------------------

.. automodule:: cosinnus.core.registries.apps
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.core.registries.attached_objects module
------------------------------------------------

.. automodule:: cosinnus.core.registries.attached_objects
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.core.registries.base module
------------------------------------

.. automodule:: cosinnus.core.registries.base
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.core.registries.urls module
------------------------------------

.. automodule:: cosinnus.core.registries.urls
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.core.registries.widgets module
---------------------------------------

.. automodule:: cosinnus.core.registries.widgets
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cosinnus.core.registries
    :members:
    :undoc-members:
    :show-inheritance:
